"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const Server_1 = require("../Server");
const decorators_1 = require("../decorators");
const _1 = require(".");
const tmp = require("tmp");
const superagent = require("superagent");
const Realm = require("realm");
describe('Test JSONError http requests', function () {
    const PORT = 5678;
    const HOST = 'localhost';
    const REALM_JS_ACCESS_TOKEN = 'eyJhbGciOiJSUzI1NiIsInR5cCI6IkpXVCJ9.eyJOb3RpZmllciI6dHJ1ZSwiU3luYyI6dHJ1ZSwiaWF0IjoxNDkyNjExMzEzfQ.Yb-o622ZYLKCQ0kTEDpBm6FsG68X9nj-OCdD4dT1G5W10fjhsTdUJiR1uYBilZPqgZEmIdDgd59rDpEjnqDhBCjTzpbsMVBGQrHj3B5eW4oGvxDkdqjR_fjwc5-zH3BeXMd9UAj13bLrxLsM0_g1FXIjmXCOK7YBrL0kKYAI2IVjqAGsI8zThhmbqxDvBeD8TVPc-brBZvXXHPO63ierJevjtZRz7mg_oV-B13gXXIxy2jlnevqFyBVRF6cd3bJmIpLUXHecQXqDGDeLaVlo2NDcnxl5OoVBN1QUSxptgQc-FIq-5qtxZXHooIJUpKQwtD2mBkJ-HBpxWbQR2C90UA';
    let SampleService = class SampleService {
        shouldReturnJSON(request) {
            throw new _1.JSONError({
                title: 'Oh No'
            });
        }
        shouldThrowBubbledException() {
            throw new Error('Internal Server Error');
        }
    };
    __decorate([
        decorators_1.Get('/a'),
        __metadata("design:type", Function),
        __metadata("design:paramtypes", [Object]),
        __metadata("design:returntype", void 0)
    ], SampleService.prototype, "shouldReturnJSON", null);
    __decorate([
        decorators_1.Get('/b'),
        __metadata("design:type", Function),
        __metadata("design:paramtypes", []),
        __metadata("design:returntype", void 0)
    ], SampleService.prototype, "shouldThrowBubbledException", null);
    SampleService = __decorate([
        decorators_1.ServiceName('sample'),
        decorators_1.BaseRoute('/sample')
    ], SampleService);
    let server;
    let tmpDir;
    before(() => __awaiter(this, void 0, void 0, function* () {
        tmpDir = tmp.dirSync();
        Realm.clearTestState();
        Realm.Sync.setFeatureToken(REALM_JS_ACCESS_TOKEN);
        server = new Server_1.Server({
            port: PORT,
            logLevel: 'off',
            dataPath: tmpDir.name,
        });
        server.addService(new SampleService(), {});
        yield server.start();
    }));
    after(() => __awaiter(this, void 0, void 0, function* () {
        Realm.clearTestState();
        if (server) {
            yield server.shutdown();
        }
    }));
    it('should be able to serialize a JSONError as a 400 bad request', function () {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const response = yield superagent.get(`http://${HOST}:${PORT}/sample/a`);
            }
            catch (err) {
                chai_1.expect(err.response.body["code"]).to.eq(400);
                chai_1.expect(err.response.body["title"]).to.eq('Oh No');
            }
        });
    });
    it('should throw an internal server error', function () {
        chai_1.expect(() => __awaiter(this, void 0, void 0, function* () {
            const response = yield superagent.get(`http://${HOST}:${PORT}/sample/b`);
        })).to.throw;
    });
});
//# sourceMappingURL=JSONError.spec.js.map